interface BuilderBase<T> {
  /**
   * Sets properties from the given builder to this builder.
   * @returns {Builder} This builder instance.
   */
  useAsBase(builder: T): T;
}

/**
 * A class implementing this interface can build an object of the given type with the values set as part of the classic
 * builder pattern.
 * T is the type of object that can be built.
 * @template T
 */
export interface Builder<T> extends BuilderBase<Builder<T>> {
  /**
   * Builds and returns the object with the values set.
   * @returns {T} The object built from the values set.
   */
  build(): T;
}

export type BuilderFromBase = BuilderBase<BuilderFromBase>;
