import { AbstractGearBuilder } from "./abstractGearBuilder";
import { Vector } from "../../../../maths/vector";
import { Arrow } from "../../../../shapes/arrow";
import { TextDisplayer } from "../../../dataDisplayers/text/textDisplayer";
import { BaseStyle } from "../../../../styles/baseStyle";
import { HasColourScheme } from "../../../../mixins/builders/hasColourScheme";
import { HasTextStyle, HasTextPosition } from "../../../../mixins/builders/text";
import { applyMixins } from "../../../../mixins/multiInherit";
import { Text } from "../../../../text/text";
import { HasFont } from "../../../../mixins/builders/hasFont";

/**
 * Represents a component that can builder a gear component that displays the current gear and a shift prompter in the
 * shape of an arrow on the top left side (relative to the gear text)
 */
export class ArrowShifterGearBuilder extends AbstractGearBuilder {
  protected shifterPosition: Vector;
  protected shifterStyle: BaseStyle;
  protected arrowScale: number;

  public setShifterPosition(shifterPosition: Vector): this {
    this.shifterPosition = shifterPosition;
    return this;
  }

  public setShifterStyle(shifterStyle: BaseStyle): this {
    this.shifterStyle = shifterStyle;
    return this;
  }

  public setArrowScale(arrowScale: number): this {
    this.arrowScale = arrowScale;
    return this;
  }

  /**
   * @override
   * @inheritDoc
   */
  protected createShiftPrompt(): Arrow {
    let arrow = new Arrow(this.arrowScale, this.shifterStyle, this.shifterPosition, this.shifterPosition);
    // Angle up
    arrow.setAngle(1.5 * Math.PI);
    return arrow;
  }

  /**
   * @override
   * @inheritDoc
   */
  protected createTextDisplayer(): TextDisplayer {
    return new TextDisplayer(new Text(this.font, "", this.textPosition, this.textStyle));
  }

  /**
   * @override
   * @inheritDoc
   */
  public useAsBase(builder: ArrowShifterGearBuilder): ArrowShifterGearBuilder {
    super.useAsBase(builder);
    this.setArrowScale(builder.arrowScale);
    this.setFont(builder.font);
    this.setTextPosition(builder.textPosition);
    this.setTextStyle(builder.textStyle);
    this.setShifterStyle(builder.shifterStyle);
    this.setShifterPosition(builder.shifterPosition);
    return this;
  }
}

export interface ArrowShifterGearBuilder extends HasColourScheme, HasTextStyle, HasTextPosition, HasFont {}
applyMixins(ArrowShifterGearBuilder, [HasColourScheme, HasTextStyle, HasTextPosition, HasFont]);
