import { Drawable } from "../../drawable";

/**
 * Represents a data displayer than can draw to a canvas.
 *
 * T is the type/object that will be used to perform updates.
 * @template T
 */
export abstract class AbstractDataDisplayer<T> implements Drawable {
  /**
   * Updates with data sent via an object.
   * @param {T} data - the data object.
   */
  public abstract update(data: T): void;

  public abstract draw(ctx: CanvasRenderingContext2D): void;
}
