/**
 * Represents a turbo
 */
export class Turbo {
  private currBoost = 0;

  /**
   * @class
   * @param {number} MAX_BOOST - the maximum boost this turbo can generate.
   */
  constructor(private readonly MAX_BOOST: number) {}

  /**
   * Sets the current boost value.
   * @param {number} boost - the value to set.
   */
  public setBoost(boost: number): void {
    if (typeof boost !== "undefined") this.currBoost = boost;
  }

  /**
   * @returns {number} The maximum boost value.
   */
  public getMaxBoost(): number {
    return this.MAX_BOOST;
  }

  /**
   * @returns {number} The current boost value.
   */
  public getBoost(): number {
    return this.currBoost;
  }

  /**
   * @returns {number} The normalised boost value.
   */
  public getNormBoost(): number {
    // Normalise from range [-1,1] to [0,1]
    return (this.currBoost / this.MAX_BOOST + 1) / 2;
  }
}
